@@ -1,6 +1,7 @@
 import random
 import string
 from django.conf import settings
+from django.contrib.auth import get_user_model
 from django.db import models
 from django.dispatch import receiver
 from django.db.models.signals import pre_save, post_save
@@ -9,6 +10,10 @@ from djangoldp.models import Model
 from .permissions import CustomerPermissions, ProjectPermissions, ProjectMemberPermissions
 
 from .views import ProjectMembersViewset
+import logging
+
+logger = logging.getLogger('djangoldp')
+
 
 class Customer(Model):
     name = models.CharField(max_length=255, null=True, blank=True)
@@ -123,11 +128,12 @@ def fix_user_hubl_workaround_493(sender, instance, **kwargs):
         try:
             request_user = getattr(instance, MODEL_MODIFICATION_USER_FIELD, None)
             if request_user is None:
-                raise Exception()
+                raise Exception('request user was unexpectadly None!')
             user = get_user_model().objects.get(pk=request_user.pk)
             instance.user = user
             instance.save()
-        except:
+        except Exception as e:
+            logger.error('error in fix_user_hubl_workaround_493.. ' + str(e))
             if instance.pk is not None:
                 instance.delete()
 
